@@ -1,4 +1,9 @@
 from __future__ import annotations
+import os
+os.environ["HF_HUB_OFFLINE"] = "1"
+os.environ["TRANSFORMERS_OFFLINE"] = "1"
+os.environ["TOKENIZERS_PARALLELISM"] = "false"
+os.environ["TRANSFORMERS_NO_ADVISORY_WARNINGS"] = "1"
 import threading,re,urllib.request,m3u8_To_MP4,subprocess,time,yt_dlp,fitz
 import os,unicodedata,requests,shutil,tempfile, hashlib,logging,glob,re
 import json,math,pytesseract,cv2,PyPDF2,argparse,sys,whisper,pytesseract
